#
# spec file for package btop
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define ROCm_version 6.4.0
Name:           btop
Version:        1.4.2+git20250501.274d0c7
Release:        1.1
Summary:        Usage and stats for processor, memory, disks, network and processes
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/aristocratos/btop
Source0:        %{name}-%{version}.tar.gz
Source1:        https://github.com/ROCm/rocm_smi_lib/archive/refs/tags/rocm-%{ROCm_version}.tar.gz#/rocm_smi_lib-rocm-%{ROCm_version}.tar.gz
Source99:       btop-rpmlintrc
Patch0:         Makefile.diff
BuildRequires:  coreutils
BuildRequires:  cmake
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  sed
%if 0%{?suse_version} < 1550
BuildRequires:  gcc13-c++
%define cxxflags CXXFLAGS="%{optflags} -fPIE"
%define cxxopt CXX="g++-13"
### Throws:
# ... relocation R_X86_64_32S against hidden symbol `_ZTVN3fmt3v1012format_errorE' can not be used when
#   making a PIE object ..." error when '-pie' is used
#%%define lddopt LDCXXFLAGS="-ldl -lpthread -pie -DFMT_HEADER_ONLY"
#####
%define lddopt LDCXXFLAGS="-ldl -lpthread -DFMT_HEADER_ONLY"
%else
BuildRequires:  gcc-c++ >= 11
BuildRequires:  lowdown
%define cxxflags %{nil}
%define cxxopt %{nil}
%define lddopt %{nil}
%endif

%description
Resource monitor that shows usage and stats for processor, memory, disks,
network and processes. C++ version and continuation of bashtop and bpytop.

%prep
%autosetup -p0
cd %{_builddir}/%{name}-%{version}
mkdir -vp %{_builddir}/%{name}-%{version}/lib/rocm_smi_lib
tar zxf %{SOURCE1} -C %{_builddir}/%{name}-%{version}/lib/rocm_smi_lib --strip-components=1

%build
###
### RSMI_STATIC will break with gcc-14, as of <= v6.1.2 (20240606)
###
%make_build %{cxxflags} %{cxxopt} %{lddopt} RSMI_STATIC=true

%install
%make_install %{cxxopt} %{lddopt} PREFIX=%{_prefix}
chmod -c 644 %{buildroot}%{_datadir}/%{name}/themes/*.theme

%files
%doc CHANGELOG.md README.md
%{_bindir}/btop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/themes
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/%{name}/themes/*.theme
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%if 0%{?suse_version} > 1550
%{_mandir}/man1/%{name}.1.gz
%endif
%license LICENSE

%changelog
* Thu May  1 2025 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 1.4.2+git20250501.274d0c7:
  * v1.4.2 Bug fixes
  * Fix process arguments appearing outside proc box by replacing ASCII control codes with blankspace, issue #1080
  * perf: use string view everywhere
  * perf: avoid copies by moving string into struct
  * perf: avoid copies with capture-by-reference
  * refactor: use algorithm from <ranges>
  * refactor: remove unnecessary lamda
  * perf: use smaller enum base type
  * Update flags in help message and README
  * Fix wrong naming in documentation and error messages for force-utf argument
  * Respect the cli flags debug and force utf
  * Remove unused variable
  * Flatten cmake module path
  * CMake: Remove option to use mold
  * Some spelling + grammar fixes :)
  * Update Terminus font link
  * Fix typo
  * Fix devide by 0
  * Avoid potential uninitialzed variables
  * Avoid stack-use-after-return
  * Avoid floating-point division by 0
  * Initialize pti struct
  * Fix macos tree-mode + aggregate memory issue
  * Fix typo: Mhz -> MHz
* Mon Apr 28 2025 Scott Bradnick <scott.bradnick@suse.com>
- Update to version 1.4.1+git20250427.666d31b:
  * v1.4.1
  * CI: Pass link flags as LDFLAGS to avoid unused argument warning
  * CI: Remove debug leftover
  * Fix various typos in code, themes and workflows
  * Mark destructor noexcept and satisfy rule-of-five
  * Initialize all struct fields
  * Mark member variables private
  * Use explicit single parameter constructor
  * Ensure NUL-termination on truncation
  * Avoid repeated bounds check
  * Use O_CLOEXEC
  * Use member function instead of cast
  * Avoid copy in constructor
  * Drop trailing newlines
  * Declare local function static
  * Drop duplicate include
  * Simplify ternary expression
  * Use explicit initialization
  * Use nullptr for pointer argument
  * Add missing override annotations
  * Avoid comma operator
  * Fixed typo
  * Avoid copies in ltrim() and ltrim()
  * Avoid string copies
  * Drop unused struct members
  * Reduce variable scope
  * Avoid string copy
  * Initialize vector in one step
  * Avoid repeated lookup
  * Avoid repeated lookup
  * Avoid repeated lookup
  * Drop unnecessary string construction
  * Avoid unnecessary copy of vector
  * Avoid copies in loop iterator
  * Reserve known vector size
  * Exit loop only if element found
  * Move the config parser in it's own module
  * Adding a menu option to show bitrates in base 10 separate from the setting to show bytes/bits in base 10
  * Update README.md GCC10 -> GCC11
  * Allow MidnightBSD to build btop using the existing freebsd support.
  * Drop workarounds for GCC 10
  * CI: Bump gcc version for NetBSD
  * CMake: Downgrade lowdown not found warning to a message
  * Make arg parser function to snake_case
  * Combine help function calls in argument parser
  * Add CLI flag to specify a different config file
  * Make: Disable LTO for debug builds
  * CMake: Check LTO support only if LTO is wanted
  * CMake: Enable LTO by default only for release builds
  * Use `XDG_STATE_HOME` to save logs
  * Remove _FORTIFY_SOURCE define
  * CMake: Generate markdown page in build directory
  * CI: Test more versions and architectures for FreeBSD and NetBSD
  * CI: Test a range of current gcc and clang versions
  * CI: Bump OpenBSD release to 7.6
  * CI: Pin runner versions to get a pull request by Renovate on updates
  * Bump CMake version to 3.25 required for `LINUX` variable
  * Replace brackets with arrows in net box
  * Replace brackets with arrows in proc box
  * chore(deps): update dependency ubuntu to v24
  * Bump bundled fmt to 11.1.4
  * Add renovate.json
* Fri Apr 11 2025 Scott Bradnick <scott.bradnick@suse.com>
- Rearranging BuildRequires
- Updating ROCm to v6.4.0
- Update to version 1.4.0+git20250410.e2d8e13:
  * cmake:  link to CMAKE_DL_LIBS
  * Fix phoenix-night.theme marked as executable
  * Add Kanagawa-lotus theme
  * add Kanagawa theme
  * Bump NetBSD version to 10.1.
  * Bump FreeBSD version to 14.2.
  * Add dark version of adwaita theme: adwaita-dark
  * Update bug_report.md
  * Update feature_request.md
* Wed Feb 19 2025 scott.bradnick@suse.com
- Updating ROCm to v6.3.3
- Update to version 1.4.0+git20250213.53df78d:
  * Resetting last selection on page navigation in optionsMenu to avoid unordered_map error
  * Update Ryzen name trimming
  * Share the CPU name trimming code between platforms
  * Drop macos 12 build, add v14 and v15
  * Fix cmake-macos workflow
  * Bump version of deprecated upload-artifact step
  * Update obsolete egrep call
* Tue Jan 28 2025 Scott Bradnick <scott.bradnick@suse.com>
- Updating ROCm to v6.3.2
* Fri Dec 20 2024 scott.bradnick@suse.com
- Updating ROCm to v6.3.1
- Update to version 1.4.0+git20241214.5535f50:
  * Menu something...
  * Fix menu crash when GPU_SUPPORT=false, issue #989
* Thu Dec  5 2024 Scott Bradnick <scott.bradnick@suse.com>
- Updating ROCm to v6.3.0
* Sun Nov 10 2024 scott.bradnick@suse.com
- Update to version 1.4.0+git20241108.e17bc6b:
  * Add 'Everforest Ligth Medium' theme
  * Support intel GPUs before Gen-6 (patch from upstream)
  * intel_name_lookup_shim.c (get_intel_device_name): Fix SEGFAULT
  * Fix rsmi_measure_pcie_speeds not saving, issue #934
  * Show GPU Watt fractions when below 100W
* Sun Sep 22 2024 scott.bradnick@suse.com
- Updating ROCm to v6.2.1
- Update to version 1.4.0+git20240922.6c0cedd:
  * v1.4.0 Intel GPU support & NetBSD support
  * Added documentation for Intel GPU support and setcap command to Makefile
  * Set Intel GPU baseline max power at 10W
  * Added warnings when toggling boxes and terminal size is to small
  * Fix missing core percentages, issue #792
  * GPU fixes
  * Fix missing headers headers for GPU build on Alpine
  * Fixed includes for CC
  * Fixed Makefile and added workaround for missing asprintf with Clang
  * intel gpu frequency
  * don't namespace on x64
  * add stdio
  * intel gpu power consumption
  * intel igpu support
* Fri Aug 16 2024 scott.bradnick@suse.com
- Updating ROCm to v6.2.0
- Update to version 1.3.2+git20240805.00c9088:
  * fix: include missed out utility header.
  * Switch macos continuous build from gcc to clang
  * Add fix for disk used and free percent #791
  * Beautify command line error output and help message
  * Disable STATIC build for cmake.
  * Fix the pkg_add command in README.
  * Bump NetBSD to 10.0 in CI.
  * Update README.md with NetBSD details.
  * Ignore netbsd folder in other builds.
  * Use kvm and ifaddr defs from shared.hpp.
  * Simplify the CI command.
  * Add support for reading thermal stats.
  * Add support for reading battery stats.
  * Get the 64 bit value of physmem.
  * Add CMake build support for NetBSD.
  * Attempt to fix the CI.
  * Fix some of the memory stats.
  * Add build files for NetBSD.
  * Add NetBSD Support.
* Fri Jul 26 2024 scott.bradnick@suse.com
- Update to version 1.3.2+git20240624.e4f69cd:
  * Updated soon to be deprecated actions to latest versions
  * Removed macos-14 for now due to XCode bug when compiling with gcc
  * Removed deprecated macos-11 and add macos-13 and macos-14
  * Update spacing
  * fix io_graph_speeds parsing
  * fix divide 0 error when caculating disk usage percentage (#791)
* Thu Jun  6 2024 Scott Bradnick <scott.bradnick@suse.com>
- Updating ROCm to v6.1.2
  * Adding note about RSMI_STATIC=true not working for gcc-14
  * Possibly https://github.com/ROCm/rocm_smi_lib/issues/170 has a fix?
* Sat Jun  1 2024 scott.bradnick@suse.com
- Update to version 1.3.2+git20240601.516979b:
  * Fixed missing CPU core temps when too small to show core temp graphs, issues #792 #867
  * Fixed missing IO graphs in IO mode, issue #867
  * V1 of Phoenix Night theme
  * Add missing linker flag for static links on FreeBSD
  * Fix comments in theme files
  * fix zero temp (#467)
* Tue May 14 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding 'BuildRequires: lowdown' for manpage generation.
  * Currently TW only since lowdown isn't present in Leap
* Thu May  9 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding btop-rpmlintrc as Source99
* Wed May  1 2024 scott.bradnick@suse.com
- Removing btop_collect.cpp.diff since it was fixed upstream
- Update to version 1.3.2+git20240501.dd4ada7:
  * Fixed missing definition for ROCm static build
* Wed May  1 2024 Scott Bradnick <scott.bradnick@suse.com>
- Using '-pie' for 15.5 and 15.6 causes errors in the linking stage, removing.
- Adding btop-rpmlintrc
* Wed May  1 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adjusting btop_collect.cpp.diff to follow suggestion from
  https://github.com/aristocratos/btop/issues/837
* Wed May  1 2024 scott.bradnick@suse.com
- Update to version 1.3.2+git20240430.b48bf6a:
  * Add info text about regex filtering in help menu
  * Add regex filtering
  * Fix typo
  * Show time in days when remaining battery exceeds an estimation of 24h
  * Fix brew not finding LLVM path after release of LLVM 18
  * Remove logging for uid without username
  * osx: show uid instead of 'unknown' if no user exists with the same
  * fix: crash on osx proc box
  * fix pwr_usage not being defined correctly during rsmi collection
* Wed May  1 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding btop_collect.cpp.diff which reverts changes that were done as a part
  of https://github.com/aristocratos/btop/issues/794 and incorporated as
  https://github.com/aristocratos/btop/pull/796
- Adding ROCm tarball as Source1 vs. injecting into tarball manually
- Updating included ROCm version from 6.0.2 to 6.1.0
* Thu Feb 22 2024 scott.bradnick@suse.com
- Update to version 1.3.2+git20240218.6c66740:
  * collect: Fix reading of battery power draw on Linux
  * cmake: Remove version specifier
  * Ask for 'btop --version' in issue template
  * Include build info in binary
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 12 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding sources from 'https://github.com/rocm/rocm_smi_lib.git' to tarball
  as 'lib/rocm_smi_lib' so GPU_SUPPORT works for NVIDIA and AMD GPUs.
  * Personally, I've seen "GPU" listed in btop using a NVIDIA T1000
    dGPU as well as AMD 680M aGPU. NVIDIA required proper drivers as well
    as having nvtop and nvidia-smi working properly (if related, maybe not
    strictly required)
- Adding 'BuildRequires: cmake' so rocm_smi_lib produces:
    Building ROCm SMI static library...
    Running CMake...
    Building and linking...
    100%%-> lib/rocm_smi_lib/build/rocm_smi/librocm_smi64.a (6.2MiB)
    ROCm SMI build complete in (03s)
  and proper linking occurs
* Mon Feb 12 2024 scott.bradnick@suse.com
- Update to version 1.3.2+git20240212.fd2a2ac:
  * v1.3.2 Hotfix GPU support AMD ROCm v6
  * Fixed variable names
  * Add check for possible librocm_smi64.so.6 and check for version 7 in the function logic
  * fix: Can't detect librocm 6.0.x
  * fix: Change bad link to old rocm repository
* Mon Feb 12 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adding '-DFMT_HEADER_ONLY' for LDCXXFLAGS for Leap, otherwise builds
  fail with "fmt::v10::basic_format_args" errors
* Sun Feb 11 2024 scott.bradnick@suse.com
- Update to version 1.3.1+git20240211.9c34ac7:
  * v1.3.1 Bug fixes
  * Reuse code from init, properly log warnings and move execution in to main loop
  * collect: Share ifaddrs wrapper and use uniq_ptr-like syntax
  * bsd: Wrap kvm_t* in a uniq_ptr and share code between BSD's
  * cmake: Fix undefined reference to `kvm_openfiles' on BSD's
  * Check LC_CTYPE to set UTF-8 locale
  * fix: don't mangle memory for zombie processes
  * Add theme based on Everforest Dark Medium palette
  * Write newline at end of config file
  * Fix dynamic loading of ROCm v6
  * Fixed incorrect used and available memory for OSX
  * Fix dependencies for Continuous Build Gpu
  * Added continuous build for testing Gpu support
  * Support for dynamic loading of ROCm v6
  * Fix basic_string::_M_create exception
  * Fix missing value in battery status tuple for openbsd
  * Add battery power draw to battery inforamtion tuple for openbsd and set it to a constant
  * added ctrl+r shortcut to reload config from disk
  * SIGUSR2 signal now reloads the config
  * -DFMT_HEADER_ONLY as a compiler flag
  * btop now reacts to SIGUSR1 by reloading config
  * Make BTOP_DEBUG also work for CMake
  * CMake: Enable OpenBSD
  * Allow the Findkvm module on all BSDs
  * Fix abort in locale detection on OpenBSD
  * fix: increase interface name length to 15
  * make os compatible
  * add freebsd support for battery power
  * make discribtion in menu and settings clearer
  * Only redraw battery indicator on power change if power change option is set to true
  * add show_battery_power option to menu
  * round wattage to second decimal
  * remove redundant space
  * Show wattage next to battery remaining time when wattage could be calculated
  * add power to get_battery function output
  * add power draw calculation for battery
  * clean up if statement for battery percent calculation
  * use capacity as default for battery percentage, less complicated and matches desktop percent exactly
  * add battery percentage calculation in charge case
  * add case of calculating the remaining battery time for current/charge
  * Introduce charge in addition to energy for laptops that use charge instead of energy, this is done so that the units make more sense in this case
  * Add current_now and voltage_now to battery struct and fix naming of current_now
* Mon Jan 22 2024 scott.bradnick@suse.com
- Update to version 1.3.0+git20240111.b2df503:
  * Update README.md -> Fixed bad links
  * Undefine FORTIFY_SOURCE before setting new value when enabled
  * Added link to compile section
  * Update README.md
  * Use _FORTIFY_SOURCE=3 and put it behind a build flag
  * Bump cmake to v1.3.0
* Sun Jan  7 2024 Scott Bradnick <scott.bradnick@suse.com>
- Update for version 1.3.0+git20240107.36842a3:
  * Updating Copyright date
  * Adding 'Makefile.diff' so {CHANGELOG,README}.md live in the same DOCDIR
  * Fixing up hardcoded /usr vs. %%{_prefix}
  * Adjustments so btop builds for Leap 15.5/15.6
* Sun Jan  7 2024 scott.bradnick@suse.com
- Update to version 1.3.0+git20240107.36842a3:
  * v1.3.0 GPU Support Linux and platform support OpenBSD
  * Fixed gpu boxes visibility state not saved and removed unnecessary comments
  * Fixed config variable show_gpu_info working correctly
* Wed Jan  3 2024 scott.bradnick@suse.com
- Update to version 1.2.13+git20240103.114a98d:
  * Add flag to set the refresh rate from command line
  * Don't pass int by reference
  * Improved error handling when determining the config directory
  * Update snapcraft.yaml to fix compile
  * Remove detailed compiler check
  * Add build status for OpenBSD
  * Add compile instructions for OpenBSD
  * Fix name of job in build
  * Add Continuous Build OpenBSD
  * Change robin_hood maps to std::unordered_map
  * Squashed commit of the following:
  * Proc::draw() -> Use std::erase_if() instead of for loops
  * Fixed leftover code in GPU init logging false errors
  * Try alternative names for GPU libraries during GPU init
  * Document DEBUG flag for Makefile
  * Fix errors
  * Added more checks and debug logging
  * Return const refs
  * Remove robin_hood.h
  * Fix call to compact and missing utility include
  * Revert "Replace robin_hood map and set with STD alternative and add safeVal() function for map/vector access with fallback"
  * Replace robin_hood map and set with STD alternative and add safeVal() function for map/vector access with fallback
  * Replace robin_hood map and set with STD alternative and add safeVal() function for map/vector access with fallback
  * Fixed test-snap-can-build.yml
  * Update test-snap-can-build.yml
  * Update test-snap-can-build.yml
  * conditional compile on Big Sur and up
  * Version bump to 1.3.0 in preparation for upcoming release
  * Updated changes
  * Added swap to ignore for statvfs() since it will always fail
  * Added try->catch for get_zfs_stat_file() to avoid fs error
  * Enable macos clang
  * Update snapcraft.yaml - opengl
  * Update bug_report.md
  * Create test-snap-can-build.yml
  * simplify removal of "Apple"
  * in case apple decides to add another suffix to the cpu name
  * cut less of cpu name if frequency is not shown
  * fix array out of bounds on regular m chip
  * fix cpu version not included
  * strip "Apple" from name of Apple silicon chips
  * Fix printed model name for older Intel CPU
  * Add CMake compile instructions for macOS
  * Add cmake workflow for all platforms
  * Patch RPATH on FreeBSD, support OSX and format
  * Provide FreeBSD static release binaries
  * Clean up compile instructions
  * Properly invoke CMake to build ROCm
  * Suppress all output from ROCm build
  * Remove ROCm object files with `make clean/distclean`
  * Add GPU options for cmake based builds
  * Add check for <ranges> header
  * Move calls to find_package to where they're required
  * Bump required CMake version
  * Update compile instructions for Gpu support
  * Update changelog
  * Readme update and Makfile fixes.
  * Squashed commit of the following:
  * Added definition GPU_SUPPORT to toggle GPU related code
  * Elementarish theme: color update according to Elementary palette
  * Elementarish theme: color update according to Elementary palette
  * Add alternative key codes for Insert, Home, End
  * Add alternative Delete key code
  * Try get terminal size of "/dev/tty" if stdout fails
  * Use native POSIX polling syscalls to read input
  * initial openbsd bringup
  * Fix: Cpu gpu stats always shown when show_gpu_info is On and sizing issues
  * Quickfixes for MacOS and FreeBSD compilation.
  * Merge fix
  * Changed: cpu_graph_lower Auto defaults to cpu_graph_upper when show_gpu_info is Off
  * Added show_gpu_info setting and Auto options for cpu graphs
  * Fixed: Key 5-0 gpu box toggle
  * Squashed commit of the following:
  * Fix GPU text overflow in CPU panel, again
  * Improve 0-10 key input
  * Fix available boxes in menu & config description
  * Fix crashes when trying to open nth GPU box with only n-1 GPUs in the system
  * Fix GPU horizontal text overflow in CPU panel
  * Fix RSMI_STATIC=true and add GPU section to README.md
  * Add GPU options
  * Remove lib/rocm_smi_lib and add instructions for obtaining it to README
  * Join NVML PCIe threads only if PCIe TX/RX is supported by GPU
  * Parallelize NVML PCIe TX/RX data collection
  * Fix type: ulong -> size_t and compare std::cmp_less
  * Fix ROCm SMI makefile flags
  * Fix error when ROCm SMI static compilation fails
  * Load ROCm SMI dynamically by default, optionally statically compile and link
  * Minor changes in wording...
  * Fix Makefile dependency order and layout
  * Statically link ROCm SMI
  * Dynamically load NVML
  * Add more GPU graph types to the CPU panel
  * Fix crash when all GPU panels are open but the CPU panel is closed
  * Handle GPUs which cannot report certain stats in GPU panel
  * Handle GPUs which cannot report certain stats in btop_collect.cpp and CPU panel
  * Add missing fmt prefixes
  * Add DebugTimer class and change some Logger::error calls to Logger::debug
  * Fixed key > gpu_names check
  * Merged changes from main
  * Makefile auto detection and initial logic for excluding gpu code when libs are missing
  * Fixed debug timer for gpu
  * Bind GPU panel to 5,6,7,8,9,0 and fully implement multi-GPU support
  * Add GPU info to CPU panel
  * Add ROCm SMI backend for AMD GPU support
  * Add multi-GPU support for NVML data collection
  * Fix crash when no nvidia GPU is detected
  * Update makefile text, fix typo and adhere to contibuting guidelines
  * Make GPU window's size dynamic and integrate it with the rest of btop
  * Improve GPU side panel
  * Add GPU side panel
  * Add rudimentary, fullscreen single-GPU NVML utilization graph
* Mon Nov  6 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20231021.9edbf27:
  * Set FreeBSD workflow timeout
  * Fix scrollbar not clearing sometimes.
  * Add keybind for toggling memory display mode in PROC box
  * Add hpp files to .editorconfig
  * Minor string initialization improvement
  * fixed bug where updated disks stats overrided disk io data
  * fixed bug where updated disks stats overrided disk io data
  * made disks stat logic async
  * Fix signal list on non-linux/weird linux platforms
  * Make process thread count better readable when wider than 5 digits
  * Add option to accumulate a child's resources in parent in tree-view
  * Add CMake support
  * Add horizon theme
  * Fix short conversion of 1000-1023*iB
  * FreeBSD Github action 13.1 -> 13.2 and static libgcc and libstdc++
  * Fix for FreeBSD github action not failing "correctly"...
  * fix some warnings
  * fix core check
  * Fix getting zfs pool name with '.' char in freebsd
  * [macos] don't check /sys on macos
  * also add g++13
  * support gcc13
  * [macos] fix temp sensor on system with many cores
  * Update Makefile for partial static compilation on freebsd
  * Fix freebsd nullptr changes and makefile for gcc12 and newer
  * Better text editing
  * Convert parameters and config keys to std::string_view
  * Use nullptr instead of NULL.
  * Fix path to Linux CI file in itself
  * Fix whitespace indent -> tab indent
  * Revert fmt submodule to static fmt folder in include
  * Fix path to Linux CI file in itself
  * Retrieve load average from libc and use emplace_back where appropriate
  * Fix the makefile version in the printed banner
  * add g++12 (without a dash) detection, fix Makefile not accounting for a possibly missing gcc
  * FreeBSD swap info
  * Make process niceness signed ("nice" can take negative values)
* Fri Jun 23 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230615.7e50b03:
  * Fix integer overflows in btop_collect.cpp
  * Enable Clang as a compiler.
  * Remove pthread_exit().
  * Replace `statvfs64` with `statvfs` and define `_FILE_OFFSET_BITS=64`.
  * Include <codecvt> required by Clang.
  * Move `#include` to top level and exclude Clang from compiler version check.
  * Insert `std::` for warning `unqualified call to std::move`.
  * Include 3rd party headers with isystem to silence warnings.
  * amend! update cpu load average display
  * update cpu load average display
  * chore: remove spaces before language in code blocks
  * chore: update readme to include --recursive
  * chore: adjust worflows to recursively clone the repository
  * feat: prefer fmt submodule over copy-and-paste headers
  * println -> fmt::println
  * Readd using namespace fmt
  * fix: prefix with `fmt::` to fix ambiguous call to `format()`, that also refers to `/usr/include/c++/13.1.1/format`
  * Debug times thousand separator
  * Debug times box changes
  * btop.cpp -> fmt
  * Fix link to themes folder
* Wed Apr 26 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230318.872eb3e:
  * Silence "warning: unqualified call to 'std::move'" in clang.
  * Update everforest-dark-hard.theme
* Thu Feb 23 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20230223.471c68f:
  * readme: Add zfs_arc_cached documentation
  * Linux: subtract ZFS ARC min size from available memory
  * Replace -ftree-loop-vectorize with -ftree-vectorize.
  * Create adwaita.theme
  * fix zfs on freebsd not reporting IO
* Tue Jan  3 2023 scott.bradnick@suse.com
- Update to version 1.2.13+git20221215.c4ee41e:
  * Fixed: Makefile, VERBOSE flag now shows directory creation, Issue #480
  * Makefile: make build targets depend on directories
* Fri Dec  9 2022 scott.bradnick@suse.com
- Update to version 1.2.13+git20221130.e67a35d:
  * Removed unused statement...
  * Fixed: Use MemFree for used mem calculation if MemAvailable is greater than MemTotal.
* Mon Nov  7 2022 scott.bradnick@suse.com
- Update to version 1.2.13+git20221106.0f8498f:
  * v1.2.13 Bug fixes
  * osx: replace getnameinfo with inet_ntop
  * a comment about AF_LINK being ignored on purpose
  * FreeBSD: replace getnameinfo with inet_ntop
  * Fixed: Process nice value underflowing, issue #461
  * Add git config safe-directory inside freebsd vm
  * OSX: use the first IP of the interface
  * Added "Continuous Build FreeBSD" badge
  * Removed bad line and gcc12 install since gcc12 i preinstalled
  * Possible fix for broken xcode command line tools
  * Use gcc12 for macos12
  * FreeBSD: use the first IP of the interface
  * Use sh instead of csh
  * Update continuous-build-freebsd.yml
  * Update continuous-build-macos.yml
  * Create continuous-build-freebsd.yml
  * Add actions run for pull requests (macos) [skip actions]
  * Add actions run for pull requests (linux) [skip actions]
  * Fixed: Not picking up last username from /etc/passwd
  * make IPBUFFER_MAXSIZE an enum constant
  * use inet_ntop instead of getnameinfo
  * Show the first IP of the interface in NET box
  * Address comment
  * Fix bug in proc_tree view when showing full cmd
  * proc tree: fix width threshold to match commit message and use and/or instead of &&, ||
  * proc tree view: if there's more than 40 width left, try to print full cmd
  * macOS Ventura compile instructions
  * macOS Ventura compile instructions
  * Added autodetection for gcc12 to make compiling on macos Ventura easier.
  * Fixed: Moved up get_cpuHz() in the execution order to get better cpu clock reading.
  * Update continuous-build-macos.yml
  * Update continuous-build-macos.yml
  * Update continuous-build-linux.yml
  * Fixed: Ignore disks that fails in statvfs64() to avoid slowdowns and possible crashes.
  * fix: spelling mistake in btop.conf
  * Changed: Reverted back to sysconf(_SC_NPROCESSORS_ONLN) for Cpu core count ant let the new dynamic update fix if cores are turned on later
  * Makefile: Reverse VERBOSE bool to not stop with macOS make
  * Update README.md
  * Added more Makefile flags
  * Added: VERBOSE=true flag for Makefile to display all compiler commands and fixed so already set CXXFLAGS and LDFLAGS are displayed.
* Fri Oct  7 2022 scott.bradnick@suse.com
- Update to version 1.2.12+git20221007.3dd6a6c:
  * v1.2.12 Bug fix
  * Added: Dynamic updating of max number of CPU cores
* Fri Oct  7 2022 scott.bradnick@suse.com
- Update to version 1.2.11+git20221007.1444476:
  * v1.2.11 Quick fix for number of cores detection
  * Fixed: Number of cores wrongly detected for Ryzen in rare cases.
* Thu Oct  6 2022 Scott Bradnick <scott.bradnick@suse.com>
- Classic 'forgot to remove old .tar.gz before ci' scenario ...
* Thu Oct  6 2022 Scott Bradnick <scott.bradnick@suse.com>
- Classic 'forgot to add new .tar.gz before ci' scenario ...
* Thu Oct  6 2022 scott.bradnick@suse.com
- Update to version 1.2.10+git20221006.7a2556e:
  * v1.2.10 Bug fixes, cleanup + a new theme
  * Fixed: Cpu::collect() core count counter...
  * All but two places `const bool` have been updated
  * More const bool cleanup
  * Remove const from bool variables
  * Avoid the unnecessary use of copy constructor
  * Fix variable initialization to 'auto' for getB()
  * Forgot to update 'auto' usage wherever necessary
  * More 'No need for const & in bool'
  * No need for const & in bool
  * Changed: Using sysconf(_SC_NPROCESSORS_CONF) for number of cores instead of sysconf(_SC_NPROCESSORS_ONLN)
  * Further Cleanup Part 2
  * Further 'cleanup'
  * Further improvements
  * Clean up btop_tools.{hpp,cpp} files
  * Ignore files created by Qt Creator
* Sun Oct  2 2022 scott.bradnick@suse.com
- Update to version 1.2.9+git20221002.24f0609:
  * Fixed: Crashing when cores are offline
  * Fixed missing "#" from value
  * Fixed: Extra checks to avoid crash on trying to replace empty strings in tree mode
  * Updated README.md
  * [feature] Added Paper theme
  * Update FUNDING.yml
  * Update FUNDING.yml
  * Update README.md
* Sun Aug 28 2022 scott.bradnick@suse.com
- Update to version 1.2.9+git20220828.26ac007:
  * Fixed: Process tree filtering not case insensitive
  * v1.2.9 Bug fixes + new features and themes
  * Fixed: Memory values not clearing properly when not in graph mode in mem box
  * Cleaning up snap
  * Instructions for btop-desktop
  * Update snapcraft.yaml
  * Removing desktop launch
  * Add FreeBSD installation command
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update btop.desktop
  * Update btop.desktop
  * Add files via upload
  * Create btop.desktop
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Maybe
  * updated color change
  * Added: Option to hide the small cpu graphs for processes
  * Add Fedora/RHEL install docs
  * [fix] Color correction
  * Changed: Small graphs now show colors for each character
  * [feature] Created 'Elementarish' theme
  * Fixed: Getting selfpath on macos (fix for finding theme folder)
  * switch Logger calls to debug() to avoid filling up the logfile
  * rename zfs_pools_only option to zfs_hide_datasets, make its description clearer
  * check if at least one object was read before updating ZFS pool io in zfs_collect_pool_total_stats(), use try-catch to prevent possible crashes from int_64t conversions
  * add "?" to see help
  * Fixed: Logo transparency
  * Use fs::directory_iterator() instead of readdir() in ZFS functions, use fs::path instead of strings.
  * Move get_zfs_stat_file() and zfs_collect_pool_total_stats() functions declarations to btop_collect.cpp so they aren't included when compiling for macos and freebsd
  * Made ZFS stats collection compatible with zfs_pools_only option. ZFS pool's stat filepath points to the objset-* file when the option is disabled, otherwise it points to the pool's stats directory. Made ZFS total pool stat collection into a separate function for clean code. Also removed an unnecessary variable in the default ZFS stat collection, and changed io_ticks to track the number of reads/writes, reducing unnecessary calculations.
  * Re-implemented ZFS stat collection to be compatible with new ZFS versions, now it uses files "/proc/spl/kstat/zfs/*pool_name*/objset*". Needs additional work to be compatible with the option "zfs_pools_only".
  * Pass const string ref
  * Changed: Rewrite of process sorting and tree generation including fixes for tree sorting and mouse support
  * Add solarized_light theme
  * Add zfs_pools_only option
* Wed Jun 29 2022 scott.bradnick@suse.com
- Update to version 1.2.8+git20220629.102b6db:
  * v1.2.8 New features & themes
  * use Shared::procPath, fix Logger error type
  * Fixed kernel proc filter clearing issue + optimization
  * Optimize away clear_kernel_cache() function
  * Add tomorrow night theme
  * fix identation
  * Remove duplicate fstype setter
  * Remove forgotten debug logger calls
  * Added support for ZFS pool io stats monitoring
  * Changed: Disable battery monitoring if it fails instead of exiting
  * Add everforest-dark-hard.theme
  * Changed spaces to tabs
  * Finished kernel proc filtering.
  * Added a check for filter kernel mode
  * Added caching for kernel processes.
  * More indentation
  * Replaced my spaces with tabs
  * Indentation fix.
  * Woops that went unnoticed, didn't it?
  * Fixed menu description
  * Added linux label on the config option
  * Fixed clang-format off labels
  * Made kernel process filtering more efficient
  * Replaced $*\s with tabs
  * Fixed some formatting issues.
  * Added TUI option for kernel proc filtering.
  * Moved to correct version of the code
* Tue Jun 14 2022 scott.bradnick@suse.com
- Adjusting '/usr/bin' to '%%{_bindir}'
- Update to version 1.2.7+git20220603.83e9942:
  * Update README.md
  * Update btop.desktop
* Tue May 31 2022 Scott Bradnick <scott.bradnick@suse.com>
- Swapping out '%%{_datarootdir}' for '%%{_datadir}'.
* Tue May 31 2022 scott.bradnick@suse.com
- Update to version 1.2.7+git20220528.c3eb02f:
  * v1.2.7 Bug fixes & new features
  * Fixed: Net sync scale bug
  * Added tokyo-night & tokyo-storm theme
* Mon May 23 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220516.c257938:
  * Fix makefile to install to /usr/local instead of /usr
  * Update makefile to install/remove icons and desktop entry
  * Add desktop icon svg and png
  * Add btop.desktop
  * Added: Case insensitive process filtering
* Thu May  5 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220505.841941a:
  * Include ZFS ARC in cached/available memory on Linux
  * Fixed: Disk IO stats for individual partitions instead of whole disk
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * Update snapcraft.yaml
  * removed unneeded plugin
* Thu Apr 14 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220414.9abf849:
  * Update snapcraft.yaml
* Wed Apr 13 2022 scott.bradnick@suse.com
- Update to version 1.2.6+git20220413.4bae3c4:
  * Update continuous-build-linux.yml
  * v1.2.6 Bug fixes
  * Changed: Enter symbol to a more common variant
  * updated robin_hood.h to v3.11.5
  * Fixed: Use cpu cores avarage temp if missing cpu package temp for FreeBSD
  * Fixed: Wrong memory unit when shorten and size is less than 10
* Mon Mar  7 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.5:
  * Fixed: Fallback to less accurate UTF8 char count if conversion to
    wstring fails
  * Fixed: Small ui fixes for mem and disks
  * Added: New theme HotPurpleTrafficLight, by @pallebone
  * Fixed: title_left symbol between auto and zero in the net box is
    not displayed, by @mrdotx
  * Fixed: Mouse mappings for net box
* Mon Feb 28 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.4:
  * Optimization: Proc::draw()
  * Fixed: Ignore duplicate disks with same mountpoint
  * Changed: Restrict command line for processes to 1000 characters to fix
    utf8 conversion errors
  * Added: add "g" and "G" to vim keys, by @mohi001
* Tue Feb 15 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.3:
  * Changed: floating_humanizer() now show fractions when shortened and value
    is < 10
  * Fixed: Process tree not redrawing properly
  * Fixed: string to wstring conversion crash when string is too big
* Mon Feb 14 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.2:
  * Changed: Reverted uncolor() back to using regex to fix delay in opening
    menu when compiled with musl
  * Added: Toggle for showing free disk space for privileged or normal users
  * Added: Clarification on signal screen that number can be manually entered
* Fri Feb 11 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.1:
  * Added: Arrow only after use of "f" when filtering processes, by @NavigationHazard
  * Fixed: Fx::uncolor not removing all escapes
  * Fixed: Text alignment for popup boxes
  * Fixed: Terminal resize warning getting stuck
  * Removed: Unnecessary counter for atomic_lock
  * Added: Percentage progress to Makefile
  * Fixed: Alignment of columns in proc box when wide UTF8 characters are used
  * Fixed: Battery meter draw fix
* Tue Jan 18 2022 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.2.0:
  * Added: Support for FreeBSD, by @joske and @aristocratos
  * Fixed (again): Account for system rolling over net speeds in Net::collect()
  * Added: Theme gruvbox_material_dark, by @marcoradocchia
  * Added: Option for base 10 bytes/bits
* Wed Dec 29 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.4:
  * Fixed: Create dependency files in build directory when compiling, by @stwnt
  * Fixed: fix CPU temp fallback on macOS, by @joske
  * Changed: From rng::sort() to rng::stable_sort() for more stability
  * Fixed: in_avail() can always be zero, by @pg83
* Mon Dec 13 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.3:
  * Added: New theme ayu, by @AlphaNecron
  * Added: New theme gruvbox_dark_v2, by @pietryszak
  * Fixed: Macos cpu coretemp for Intel, by @joske
  * Added: New theme OneDark, by @vtmx
  * Fixed: Fixed network graph scale int rollover
  * Fixed: Suspected possibility of very rare stall in Input::clear()
* Sun Nov 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.2:
  * Fixed: SISEGV on macos Mojave, by @mgradowski
  * Fixed: Small optimizations and fixes to Mem::collect() and Input::get()
  * Fixed: Wrong unit for net_upload and net_download in config menu
  * Fixed: UTF-8 detection on macos
  * Fixed: coretemp iteration due to missing tempX_input, by @KFilipek
  * Fixed: coretemp ordering
* Tue Nov 16 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.1:
  * Added: Partial static build (libgcc, libstdc++) for macos
  * Changed: Continuous build macos switched to OSX 11.6 (Big Sur) and partial static build
  * Changed: Release binaries for macos switched to OSX 12 (Monterey) and partial static build
* Mon Nov 15 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.1.0:
  * Added: Support for OSX, by @joske and @aristocratos
* Tue Nov  9 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.24:
  * Changed: Collection ordering
  * Fixed: Restore all escape seq mouse modes on exit
  * Fixed: SIGINT not cleaning up on exit
- Update to upstream relaese 1.0.23:
  * Fixed: Config parser missing first value when not including version header
  * Fixed: Vim keys menu lists selection
  * Fixed: Stall when clearing input queue on exit and queue is >1
  * Fixed: Inconsistent behaviour of "q" key in the menus
* Thu Nov  4 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.22:
  * Fixed: Bad values for disks and network on 32-bit
* Tue Nov  2 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.21:
  * Fixed: Removed extra spaces in cpu name
  * Added: / as alternative bind for filter
  * Fixed: Security issue when running with SUID bit set
* Wed Oct 27 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.20:
  * Added: Improved cpu sensor detection for Ryzen Mobile, by @adnanpri
  * Changed: Updated makefile
  * Changed: Regex for Fx::uncolor() changed to string search and replace
  * Changed: Removed all use of regex with dedicated string functions
* Thu Oct 21 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.19:
  * Fixed: Makefile now tests compiler flag compatibility
* Tue Oct 19 2021 Scott Bradnick <scott.bradnick@suse.com>
- Update to upstream release 1.0.18:
  * Fixed: Makefile g++ -dumpmachine failure to get platform on some distros
- Update to upstream release 1.0.17:
  * Changed: Reverted mutexes back to custom atomic bool based locks
  * Added: Static binaries switched to building with musl + more platforms, by @jan-guenter
  * Fixed: Improved battery detection, by @jan-guenter
  * Added: Displayed battery selectable in options menu
  * Fixed: Battery error if non existent battery named is entered
* Mon Oct 18 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.16 ...
* Wed Oct 13 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.15 ...
* Thu Oct  7 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.14 ...
* Sat Oct  2 2021 Stefan Seyfried <seife+obs@b1-systems.com>
- allow to build on 15.3 also
- improve filelist (no more "files listed twice...")
* Wed Sep 29 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.11 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.10 ...
* Tue Sep 28 2021 Scott Bradnick <scott.bradnick@suse.com>
- Cleaning commented lines and changelog entries from spec file.
* Mon Sep 27 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.9 ...
* Fri Sep 24 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.6 ...
* Thu Sep 23 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.5 ...
* Wed Sep 22 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.4 ...
* Tue Sep 21 2021 Scott Bradnick <scott.bradnick@suse.com>
- Updating to version 1.0.2 ...
* Mon Sep 20 2021 Scott Bradnick <scott.bradnick@suse.com>
- Initial commit for version 1.0.1 ...
